<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Comment_Model_DbTable_Commentfiles extends Engine_Db_Table
{
  public function getFiles($params = array())
  {
    $select = $this->select()->where('comment_id =?', $params['comment_id']);
    return $this->fetchAll($select);
  }
}
