
.notification_type_comment_tagged_people:before,
.notification_type_comment_taggedreply_p:before,
.notification_type_comment_replycomment:before{
	content:"\f075";
	font-family:'Font Awesome 6 Free';
	font-weight:600;
}

/*Reaction Notification work start here*/
[class*="notification_type_activity_reacted_"]{
	position:relative;
	overflow:visible;
}
[class*="notification_type_activity_reacted_"]:before{
	content:"";
	background-repeat:no-repeat;
	background-position:0 center;
	background-size:16px;
	display:inline-block !important;
	width:16px;
	height:16px;
}
.notification_type_activity_reacted_sad:before{background-image:url(~/application/modules/Comment/externals/images/icon-sad.png);}
.notification_type_activity_reacted_haha:before{background-image:url(~/application/modules/Comment/externals/images/icon-haha.png);}
.notification_type_activity_reacted_wow:before{background-image:url(~/application/modules/Comment/externals/images/icon-wow.png);}
.notification_type_activity_reacted_angr:before{background-image:url(~/application/modules/Comment/externals/images/icon-angery.png);}
.notification_type_activity_reacted_love:before{background-image:url(~/application/modules/Comment/externals/images/icon-love.png);}

/*Emoji CSS Start Here*/
.comment_emotion_container{
  background-color:var(--theme-list-background-color);
	border-radius:10px;
	box-shadow:1px 1px 10px rgba(0, 0, 0, 0.1);
	display:none;
	position:absolute;
	width:300px;
	z-index:8;
	overflow:hidden;
}
.comment_emotion_container_inner{
	border-radius:3px;
	position:relative;
}
.comment_emotion_container_header{
	border-bottom-width:1px;
}
.comment_emotion_container_header ._headbtn,
.comment_emotion_container_header .owl-nav > div{
	float:left;
	cursor:pointer;
	height:40px;
	line-height:40px;
	padding:0;
	text-decoration:none;
	text-align:center;
	width:40px;
}
.comment_emotion_container_header ._headbtn i{
	width:24px;
	text-align:center;
	margin:0 auto;
}
.comment_emotion_container_header ._headbtn_add{
	float:right;
}
.comment_emotion_container_header .owl-nav{
	position:absolute;
	top:0;
	width:100%;
}
.comment_emotion_container_header .owl-nav > div{
	font-size:0;
	position:absolute;
}
.comment_emotion_container_header .owl-nav .owl-prev{
	left:0;
}
.comment_emotion_container_header .owl-nav .owl-next{
	right:0;
}
.comment_emotion_container_header ._headbtn_add{
	width:40px;
	text-align:center;
}
[dir="rtl"] .comment_emotion_container_header ._headbtn_add{
	text-align:center;
}
.comment_emotion_container_header ._headbtn i:before,
.comment_emotion_container_header .owl-nav > div:before{
	background-color:var(--theme-list-background-color);
	color:var(--theme-font-color-light);
	font-style:normal;
	display:block;
	font-family:'Font Awesome 6 Free';
	font-weight:600;
	font-size:15px;
	text-rendering:auto;
	-webkit-font-smoothing:antialiased;
	-moz-osx-font-smoothing:grayscale;
}
.comment_emotion_container_header .owl-nav > .owl-prev:before{content:"\f053";}
.comment_emotion_container_header .owl-nav > .owl-next:before{content:"\f054";}
.comment_emotion_container_header .owl-nav > div.disabled{
	display:none;
}
.comment_emotion_container_header ._headbtn_add i:before{
	content:"\f067";
}
.comment_emotion_container_header ._headbtn_search i:before{
	content:"\f002";
}
.comment_emotion_container_header_tabs{
	display:block;
	overflow:hidden;
	position:relative;
}
.comment_emotion_container_header_tabs .owl-stage-outer{
	float:left;
}
.comment_emotion_container_header_tabs .owl-item{
	float:left;
}
.comment_emotion_container_header_tabs .owl-item ._headbtn{
	text-align:center;
	width:100%;
}
[dir="rtl"] .comment_emotion_container_header_tabs .owl-item ._headbtn{
	text-align:center;
}
.comment_emotion_container_header_tabs .owl-item ._headbtn img{
	height:24px;
	object-fit:contain;
	margin:0 auto;
	width:24px;
}
.comment_emotion_holder .custom_scrollbar{
	height:300px !important;
	max-height:300px;
	overflow:auto;
	padding:5px;
}
/* .comment_emotion_holder .custom_scrollbar .comment_emotion_search_content{
	height:auto;
} */
 
/*Simple Icons*/
.comment_emotion_container ._simemoji{
	padding:0.3125rem;
	display:flex;
	flex-wrap:wrap;
	gap:0.25rem;
	max-height:18.75rem;
	margin:0.3125rem;
}
.comment_emotion_container ._simemoji > li{
	height:24px;
	width:24px;
}
.comment_emotion_container ._simemoji  > li img{
  max-width:24px;
}
/*Stickers*/
.comment_emotion_container ._sickers{
	display:flex;
	flex-wrap:wrap;
}
.comment_emotion_container ._sickers li{
	height:70px;
	padding:1px;
	width:33.33%;
}
.comment_emotion_container ._sickers li a{
	display:flex;
	height:100%;
	justify-content:center;
	align-items:center;
}
.comment_emotion_container ._sickers li a img{
	max-height:65px;
	max-width:65px;
}
/*Edit Post*/
.comment_emotion_container.from_bottom{
	margin-top:-23.125rem;
}
/*Search Screen*/
.comment_emotion_search_container:[style="display:block"] + .emoji_content{
	display:none;
}
.comment_emotion_search_bar{
	padding:10px;
	position:relative;
}
.comment_emotion_search_input{
	position:relative;
}
.comment_emotion_search_input:before{
	content:"\f002";
	text-align:center;
	position:absolute;
	width:25px;
	margin-top:6px;
  font-family:'Font Awesome 6 Free';
  margin-left:5px;
	font-weight:bold;
}
[dir="rtl"] .comment_emotion_search_input:before{
	text-align:center;
	margin-left:0;
	margin-right:5px;
}
.comment_emotion_search_input input[type="text"]{
	border-radius:0 !important;
	height:35px;
	padding:0 30px !important;
	width:100%;
	outline:none;
}
.comment_emotion_search_input button{
	background-image:none !important;
	background-color:transparent !important;
	border-width:0 !important;
	box-shadow:none !important;
	padding:5px;
	line-height:0;
	position:absolute;
	right:5px;
	top:0;
	bottom:0;
	outline:none;
}
[dir="rtl"] .comment_emotion_search_input button{
	left:0;
	right:inherit;
}
.comment_emotion_search_input button:before{
	color:var(--theme-font-color);
}
.comment_emotion_search_cat_item{
	float:left;
	padding:5px;
	width:50%;
}
[dir="rtl"] .comment_emotion_search_cat_item{
	float:right;
}
.comment_emotion_search_cat_item a{
	border-radius:3px;
	color:#fff !important;
	display:block;
	padding:2px 10px;
	text-decoration:none !important;
}
.comment_emotion_search_cat_item a:hover{
	opacity:.7;
}
.comment_emotion_search_cat_item a img{
	height:26px;
	float:left;
	margin-right:5px;
	width:25px;
}
[dir="rtl"] .comment_emotion_search_cat_item a img{
	float:right;
	margin-left:5px;
	margin-right:0;
}
.comment_emotion_search_cat_item a span{
	display:block;
	font-size:12px;
	font-weight:bold;
	overflow:hidden;
	line-height:26px;
}
.comment_emotion_search_noresult{
	text-align:center !important;
}
.comment_emotion_search_noresult > i{
	font-size:70px;
	margin:40px 0 10px;
}
.comment_emotion_search_noresult > span{
	display:block;
	font-size:14px;
}

/*Emojies Container*/
.activity_gif_container_inner{
	position:relative;
}
.activity_emoji_holder{
	height:330px;
}
.activity_gif_holder{
	height:300px;
}
.activity_gif_holder .tip{
	margin:10px;
}
.activity_gif_holder .custom_scrollbar{
	height:255px !important;
	max-height:255px;
  overflow:auto;
}
.activity_emoji_holder .custom_scrollbar{
	height:300px !important;
	max-height:300px;
	overflow:auto !important;
}
.activity_emoji_holder .emoji_listing{
	padding:0.625rem;
}
.activity_emoji_holder .emoji_listing > ul > li + li{
	margin-top:0.625rem;
}
.activity_emoji_holder .emoji_listing > ul > li > span{
	color:var(--theme-font-color-light);
	display:block;
	margin-bottom:0.3125rem;
}
.activity_emoji_holder .emoji_listing li ul{
	display:flex;
	flex-wrap:wrap;
	gap:0.3125rem;
}
.activity_emoji_holder .emoji_listing li ul li{
	font-size:1.25rem;
	height:2.125rem;
	width:2.125rem;
	display:flex;
	align-items:center;
	justify-content:center;
}
.feeling_emoji_content_footer{
	border-top-width:1px;
	padding:6px 10px;
	text-align:center;
}
.feeling_emoji_content_footer a{
	padding:5px;
}
.feeling_emoji_content_footer a.active{
  border-top:2px solid;
}
.feeling_emoji_content_footer a img{
	height:16px;
	width:16px;
}
/*GIF Container*/
.activity_gif_container_inner ul li a._activitygif_gif{
	display:block;
	text-align:center;
}
.activity_gif_container_inner ul li a._activitygif_gif img{
	max-width:100%;
	width:100%;
}

/*Sticker Store Popup*/
.comment_emotion_store{
	border-radius:3px;
	overflow:hidden;
	height:530px;
	width:688px;
}
.comment_emotion_store_header{
	background-image:url(~/application/modules/Comment/externals/images/store-header-bg.png);
	background-position:center bottom;
	background-size:100% auto;
	background-repeat:no-repeat;
	height:190px;
	box-shadow:0 0 5px rgba(0, 0, 0, .3);
	position:relative;
	z-index:1;
}
.comment_emotion_store_header_cont{
	padding-top:60px;
}
.comment_emotion_store_header_cont_title{
	font-size:27px;
	margin-bottom:5px;
	font-weight:bold;
}
.comment_emotion_store_header_cont_des{
	font-size:14px;
}
.comment_emotion_store_content{
	overflow:auto;
	height:340px;
}
.comment_emotion_store_content_inner{
	padding:10px;
}
.comment_emotion_store_item{
	float:left;
	padding:5px;
	width:50%;
}
[dir="rtl"] .comment_emotion_store_item{
	float:right;
}
.comment_emotion_store_item > div{
	box-shadow:0 0 5px rgba(0, 0, 0, .1);
	border-radius:3px;
	overflow:hidden;
	padding:10px;
}
.comment_emotion_store_item_main_icon{
	margin-right:10px;
	height:90px;
	width:90px;
}
[dir="rtl"] .comment_emotion_store_item_main_icon{
	margin-left:10px;
	margin-right:0;
}
.comment_emotion_store_item_main_icon img{
	max-height:85px;
	max-width:85px;   
}
.comment_emotion_store_item_top_icons{
	flex:1;
}
.comment_emotion_store_item_top_icons div{
	height:40px;
	margin:0 0 8px 8px;
	text-align:center;
	width:40px;
}
[dir="rtl"] .comment_emotion_store_item_top_icons div{
	margin:0 8px 8px 0;
}
.comment_emotion_store_item_top_icons div img{
	max-height:40px;
	max-width:40px;
}
.comment_emotion_store_item_btm{
	clear:both;
	padding-top:10px;
}
.comment_emotion_store_item_btm_btns{
	margin-left:15px;
}
[dir="rtl"] .comment_emotion_store_item_btm_btns{
	margin-left:0;
	margin-right:15px;
}
html .comment_emotion_store_item_btm_btns button{
	padding:5px 10px;
}
.comment_emotion_store_item_btm_title{
	flex:1;
	font-weight:var(--theme-font-weight-bold);
	overflow:hidden;
	padding-top:5px;
	white-space:nowrap;
	text-overflow:ellipsis;
}
.comment_emotion_store_preview_back_link{
	background-color:var(--theme-list-background-color);
	border-bottom-width:0.0625rem;
	padding:0.3125rem 0.625rem;
	line-height:2.5rem;
}
.comment_emotion_store_preview_back_link > a{
	color:var(--theme-font-color) !important;
	text-decoration:none !important;
}
.comment_emotion_store_preview_back_link > a i{
	margin-right:5px;
	font-size:16px;
	vertical-align:middle;
}
[dir="rtl"] .comment_emotion_store_preview_back_link > a i{
	margin-left:5px;
	margin-right:0;
}
.comment_emotion_store_preview_cont{
	height:490px;
	padding:15px;
	overflow:auto;
}
.comment_emotion_store_preview_info_img img{
	max-height:90px;
	max-width:90px;
}
.comment_emotion_store_preview_info_cont{
	overflow:hidden;
}
.comment_emotion_store_preview_info_cont > div{
	margin-bottom:10px;
}
.comment_emotion_store_preview_title{
	font-weight:bold;
	font-size:16px;
}
.comment_emotion_store_preview_btn button{
	padding:5px 10px;
}
.comment_emotion_store_preview_stickers{
	border-radius:3px;
	padding:10px;
	margin:10px 2px 0;
	box-shadow:0 0 5px rgba(0, 0, 0, .1);
}
.comment_emotion_store_preview_stickers_icon{
	height:100px;
	padding:10px;
	text-align:center;
	width:20%;	
}
[dir="rtl"] .comment_emotion_store_preview_stickers_icon{
	float:right;
}
.comment_emotion_store_preview_stickers_icon span{
	background-position:center center;
	background-size:contain;
	background-repeat:no-repeat;
	height:100%;
	display:block;
	width:100%;
}
@media only screen and (max-width:979px){
	.comment_emotion_store{width:100%;}
}
@media only screen and (max-width:768px){
	.comment_emotion_store_item{width:100%;}
}
@media only screen and (max-width:480px){
	.comment_emotion_store_preview_stickers_icon{height:130px;}
	.comment_emotion_store_preview_stickers_icon{padding-top:10px;}
	.comment_emotion_store_preview_stickers_icon{width:33%;}
}

/*Reaction Box CSS Start Here*/
.comment_hoverbox{
	border-width:1px;
	opacity:0;
	height:0;
	visibility:hidden;
	width:0;
	position:absolute;
	z-index:200;
	background:#fff;
	font-size:0;
	padding:0;
	text-align:left;
	border-radius:70px;
	white-space:nowrap;
	box-shadow:0 8px 2px -6px rgba(0, 0, 0, 0.29);
	margin-top:-48px;
}
[dir="rtl"] .comment_hoverbox{
	text-align:right;
}
.comment_hoverbox_wrapper._show .comment_hoverbox{
	visibility:visible;
	opacity:1;
	height:48px;
	width:auto;
}
.comment_hoverbox_wrapper._close .comment_hoverbox{
	visibility:hidden;
	opacity:0;
}
.activity_feed .comment_hoverbox{
	z-index:10;
}
.comment_hoverbox > span{
	cursor:pointer;
	display:inline-block;
	height:48px;
	margin:0;
	padding:0;
	position:relative;
	transform:scale(1, 1) translateY(.0001px);
	transform-origin:50% 100%;
	width:48px;
	transform:translateY(50px);
	opacity:0;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span{
	opacity:1;
	transform:translateY(0);
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span {
	-webkit-transition:all 300ms ease;
	-moz-transition:all 300ms ease;
	-o-transition:all 300ms ease;
	transition:all 300ms ease;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(n) {
	transition-delay:calc(100ms * n);
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span {
	-webkit-transition:all 300ms ease;
	-moz-transition:all 300ms ease;
	-o-transition:all 300ms ease;
	transition:all 300ms ease;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(1) {
	transition-delay:100ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(2) {
	transition-delay:200ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(3) {
	transition-delay:300ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(4) {
	transition-delay:400ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(5) {
	transition-delay:500ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(6) {
	transition-delay:600ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(7) {
	transition-delay:700ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(8) {
	transition-delay:800ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(9) {
	transition-delay:900ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(10) {
	transition-delay:1000ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(11) {
	transition-delay:1100ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(12) {
	transition-delay:1200ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(13) {
	transition-delay:1300ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(14) {
	transition-delay:1400ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(15) {
	transition-delay:1500ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(16) {
	transition-delay:1600ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(17) {
	transition-delay:1700ms;
}
.comment_hoverbox_wrapper._show .comment_hoverbox > span:nth-child(18) {
	transition-delay:1800ms;
}

.comment_hoverbox_wrapper._show span .comment_hoverbox_btn_icon{
	transform:scale(.8, .8) translate(0, 0);
	transition:transform 200ms ease;
}
.comment_hoverbox_btn_icon i{
	background-repeat:no-repeat;
	background-size:100%;
	display:block;
	height:48px;
	line-height:1;
	width:48px;
	border-radius:50px;
}
.comment_hoverbox span .text{
	left:50%;
	position:absolute;
	text-align:center;
	top:-28px;
	transform:translateX(-50%);
}
.feed_item_option_share .comment_hoverbox > span:first-child .text{
	transform:translateX(-10%);
	left:0%;
}
.comment_hoverbox span .text div{
	background-color:rgba(0, 0, 0, .75);
	border-radius:10px;
	box-sizing:border-box;
	color:#fff;
	display:inline-block;
	font-size:12px;
	font-weight:bold;
	line-height:20px;
	max-width:100%;
	opacity:0;
	overflow:hidden;
	padding:0 8px;
	text-decoration:none;
	text-overflow:ellipsis;
	transition:opacity 50ms ease;
}
.comment_hoverbox span:hover .comment_hoverbox_btn_icon{
	transform:scale(1, 1) translate(0, -6px);
}
.comment_hoverbox span:hover .text div{
	opacity:1;
}


/*Composer*/
.comment_comments{
	width:100%;
}
.comment_comments > ul{
	overflow:visible;
}
.comment_comments > form{
  padding:0.9375rem 0 0.625rem;
	clear:both;
	border-top-width:1px;
	border-top-color:var(--theme-border-color);
}
.comment_comments > form .core_loading_cont_overlay{
	background-size:1.25rem;
}
.comment_comments form.advcomment_form > div{
	display:table-cell;
	vertical-align:top;
}
.comment_comments form.advcomment_form > div.comment_form_container{
	padding-left:10px;
	width:100%;
}
[dir="rtl"] .comment_comments form.advcomment_form > div.comment_form_container{
	padding-left:0;
	padding-right:10px;
}
.comment_comments form .comment_form_main{
	background-color:var(--theme-list-background-color-hover);
	padding:0.5rem 0.75rem;
	border-radius:0.625rem;
	border:1px solid var(--theme-border-color);
	display:flex;
	gap:5px;
	flex-direction:column;
}
.comment_comments div.comment_form_container div.comment_form{
	position:relative;
	border-radius:20px;
	width:100%;
	margin-right:10px;
	padding:2px 5px 0 5px;
	display:flex;
	justify-content:flex-end;
	flex-wrap:wrap;
}
[dir="rtl"] .comment_comments div.comment_form_container div.comment_form{
  margin-right:0;
	margin-left:10px;
}
.comment_comments div.comment_form_container div.comment_form .mentions-input-box{
	flex:1;
  flex-grow:1;
}
.comment_comments .comment_form .jqueryHashtags .highlighter,
.comment_comments div.comment_form_container div.comment_form textarea{
	border-width:0 !important;
	border-radius:0;
	font-size:var(--theme-font-size);
	padding:0 !important;
	width:100%;
	overflow:hidden;
	position:relative;
	margin:0 !important;
	background-color:transparent;
	word-break:break-word;
	font-family:inherit;
	outline:transparent !important;
}
.comment_comments div.comment_form_container div.comment_form textarea{
	background-color:transparent;
	display:flex;
}
.comment_comments .comment_form .jqueryHashtags .highlighter{
	-webkit-text-fill-color:transparent !important;
}
.comment_comments .comment_form .jqueryHashtags .highlighter{
	overflow:hidden;
	position:absolute;
}
.comment_comments div.comment_post_options{
	display:flex;
	align-items:center;
	justify-content:space-between;
	gap:5px;
}
.comment_comments div.comment_form_container .comment_post_icons{
	display:flex;
	gap:5px;
}
.comment_comments div.comment_form_container .comment_post_icons > span{
	float:left;
	position:relative;
}
[dir="rtl"] .comment_comments div.comment_form_container .comment_post_icons > span{
	float:right;
}
.comment_comments div.comment_form_container .comment_post_icons > span > a{
	border-radius:50%;
	display:flex;
	justify-content:center;
	align-items:center;
	height:24px;
	width:24px;
}
.comment_comments div.comment_form_container .comment_post_icons > span > a:hover{
	background-color:var(--theme-list-background-color-hover);
}
.comment_comments div.comment_form_container .comment_post_icons > span > a > i{
	height:16px;
	width:16px;
	display:flex;
}
.comment_comments div.comment_form_container .comment_post_icons > span > a > i svg{
	fill:var(--theme-font-color-light);
	height:100%;
	width:100%;
}
.comment_comments div.comment_form_container .comment_post_icons > span:hover > a > i svg{
	fill:var(--theme-font-color);
}
.comment_comments div.comment_form_container .comment_post_icons > span > a:before{
	color:var(--theme-font-color-light);
}
.comment_comments div.comment_form_container .comment_post_icons > span:hover > a:before{
	color:var(--theme-font-color);
}
.comment_comments form .comment_form_main button{
	background-color:transparent !important;
	border-width:0 !important;
	box-shadow:none !important;
	border-radius:50%;
	min-width:24px;
	height:24px;
	padding:0;
}
.comment_comments form  .comment_form_main button svg{
	fill:var(--theme-color);
	height:1rem;
	width:1rem;
}
.comment_comments form .comment_form_main button.disabled svg{
	fill:var(--theme-font-color-light);
  opacity:.3;
}

.comment_comments div.comment_form_container .upload_file_cnt{
	margin:0.625rem 0 0;
	overflow:hidden;
	display:flex;
	flex-wrap:wrap;
	gap:0.3125rem;
}
.comment_comments div.comment_form_container div.uploaded_file{
	border-radius:0.3125rem;
	overflow:hidden;
	border-width:1px;
	background-color:var(--theme-list-background-color);
	position:relative;
	height:105px;
	width:105px;
}
.comment_comments div.comment_form_container div.uploaded_file img{
	object-fit:cover;
	height:100%;
	width:100%;
}
.comment_comments div.comment_form_container div.uploaded_file img._loading{
	height:16px;
	width:16px;
	margin:40px auto;
	display:block;
}
.comment_comments div.comment_form_container div.uploaded_file .cancel_upload_file{
	color:#fff;
	position:absolute;
	top:5px;
	right:5px;
	text-decoration:none !important;
	font-size:17px;
	line-height:15px;
}
[dir="rtl"] .comment_comments div.comment_form_container div.uploaded_file .cancel_upload_file{
	left:5px;
	right:inherit;
}
.comment_comments .comment_play_btn{
	border:1px solid rgba(255, 255,255, .6);
	font-size:17px;
	position:absolute;
	left:50%;
	top:50%;
	transform:translate(-50%, -50%);
	color:#fff !important;
	height:40px;
	width:40px;
	background-color:rgba(0, 0, 0, .8);
	border-radius:50%;
	text-align:center;
	line-height:37px;
	text-decoration:none !important;
	padding-left:5px;
}
.comment_comments div.comment_form_container div.uploaded_file .cancel_upload_file:before,  .comment_play_btn:before{
	text-shadow:0 0 5px rgba(0, 0, 0, .5);
}
.comment_comments .sticker_preview,
.comment_comments .gif_preview{
	position:relative;
	display:flex;
	align-items:flex-start;
	gap:0.625rem;
	margin-top:0.625rem;
}
.comment_comments .sticker_preview img,
.comment_comments .gif_preview img{
	max-width:9.375rem;
}
.comment_comments .sticker_preview a,
.comment_comments .gif_preview a{
	background-color:var(--theme-list-background-color-alt);
	color:var(--theme-font-color);
	height:24px;
	width:24px;
	display:flex;
	align-items:center;
	justify-content:center;
	border-radius:50%;
}
.comment_link_item{
	background-color:var(--theme-list-background-color);
	border-radius:var(--theme-item-radius);
	border-width:1px;
	margin:5px 0 0;
	overflow:hidden;
}
.comment_link_item > a{
  display:flex;
}
.comment_link_item *{
	text-decoration:none !important;
}
.comment_link_item_img{
	min-width:100px;
	max-width:100px;
	height:100px;
}
.comment_link_item_img img{
	border-right-width:1px;
	height:100px;
	object-fit:cover;
	width:100px;
}
.comment_link_item_cont{
	padding:var(--theme-item-spacing);
	display:flex;
	flex-direction:column;
	justify-content:center;
	position:relative;
}
.comment_link_item_title{
	font-weight:600;
	font-size:110%;
	margin-bottom:5px;
	word-break:normal;
	font-family:Georgia, serif;
	display:-webkit-box;
	-webkit-line-clamp:2;
	-webkit-box-orient:vertical;
	overflow:hidden;
}
.comment_link_item_source{
	word-break:normal;
}

/*Edit Comment*/
.comment_comments > ul > li .comment_replies .comment_edit {
	padding-left:0.625rem;
}
/*Comment Options*/
.comment_options > ul{
	display:flex;
	align-items:center;
	gap:0.9375rem;
	margin:0.3125rem 0;
}
.comment_options li a{
	color:var(--theme-font-color);
	display:flex;
	align-items:center;
	gap:5px;
	text-decoration:none !important;
	line-height:1rem;
}
.comment_options li a i{
	background-size:1rem;
	height:1rem;
	width:1rem;
}
.comment_options li svg{
	fill:var(--theme-font-color);
	height:100%;
	width:100%;
}
.comment_options li.feed_item_option_unlike svg{
	display:none;
}
.comment_options li a span{
	font-weight:var(--theme-font-weight-bold);
}
.comment_list_wrapper .comment_comments > form{
	margin-top:0.9375rem;
}

/*Comments*/
.comment_comments > ul > li{
	padding:0.625rem 0;
  display:table;
  overflow:visible;
  width:100%;
}
.comment_comments > ul > li > div{
	display:table-cell;
	vertical-align:top;
}
.comment_comments > ul > li > div a{
	color:var(--theme-font-color);
}
.comment_comments .comments_author_photo{
	overflow:visible;
}
.comment_comments .comments_author_photo img{
	height:35px;
	width:35px;
	border:0;
	border-radius:50px;
}
.comment_comments .comments_info{
	position:relative;
  font-size:inherit;
  padding:0 0 0 10px;
  overflow:visible;
  width:100%;
}
[dir="rtl"] .comment_comments .comments_info{
	padding:0 10px 0 0 !important;
}
.comment_comments .comments_info .comments_author{
	font-size:var(--theme-font-size-small);
	float:none !important;
}
.comment_comments .comments_info .comments_author a{
	font-weight:var(--theme-font-weight-bold);
}
.comment_comments .comments_info ._emojiicon{
	vertical-align:middle;
}
.comment_comments .emoji img{
	margin-top:0.625rem;
	max-width:6.25rem;
}
.comment_comments .comment_reply_form{
  margin:0.9375rem 0;
}
.comments_reply_likes_total a{
	text-decoration:none !important;
}
.comment_comments .comments_body,
.comment_comments .comments_reply_body{
	font-size:var(--theme-font-size-small);
	word-break:break-word;
}
.comment_comments .comments_body a,
.comment_comments .comments_reply_body a{
  word-break:break-word;
	font-weight:var(--theme-font-weight-bold);
}
.comment_comments .comments_content{
	background-color:var(--theme-list-background-color-hover);
	display:inline-block;
	padding:0.5rem 0.75rem;
	border-radius:1.25rem;
	max-width:90%;
}
.comments_likes_total{
	background-color:var(--theme-list-background-color);
	border-radius:20px;
	box-shadow:0 1px 3px 0 #a9a9a9;
	padding:4px 5px;
	margin-left:-15px;
	top:10px;
	position:relative;
	display:inline-block;
	font-size:var(--theme-font-size-small);
	line-height:1;
}
[dir="rtl"] .comments_likes_total{
	margin-left:0;
	margin-right:-15px;
}
.comments_likes_total .comments_likes_reactions a{
	border-radius:50px;
}
.comments_likes_total > a{
	color:var(--theme-font-color-light);
	position:relative;
	top:1px;
}
.comment_comments .comments_date{
	font-size:var(--theme-font-size-small);
	margin:0.3125rem 0 0 0.625rem;
	clear:both;
	overflow:visible;
}
[dir="rtl"] .comment_comments .comments_date{
	margin:0.3125rem 0.625rem 0 0;
}
.comment_comments .comments_date > li{
	display:inline-block;
	vertical-align:middle;
	margin-right:5px;
	float:none;
}
[dir="rtl"] .comment_comments .comments_date > li{
	float:none;
	margin-left:5px;
	margin-right:0;
}
.comment_comments .comments_date > li > a{
	font-weight:var(--theme-font-weight-bold);
}
.comment_comments .comments_date > li.feed_item_option_unlike > a,
.comment_comments .comments_date > li > a:hover{
	color:var(--theme-link-color-hover);
}
.comment_comments .comments_content .giphy_image{
	margin-top:0.625rem;
	max-height:18.75rem;
	max-width:100% !important;
}
.comments_body .gif,
.comments_reply_body .gif{
	max-width:400px;
	margin:0 auto;
	text-align:center;
}
.comments_body .gif img,
.comments_reply_body .gif img{
	border-width:1px;
	max-width:100%;
}
.comment_media_container{
	margin-top:5px;
	overflow:hidden;
	position:relative;
	display:flex;
	flex-wrap:wrap;
}
.comment_media_thumb{
	background-color:#fff;
	border-width:1px;
	position:relative;
	border-radius:0.3125rem;
	overflow:hidden;
	width:140px;
}
.comment_media_thumb a{
	aspect-ratio:10/7;
	float:left;
	position:relative;
	width:100%;
}
.comment_media_thumb a span{
	background-size:cover;
	background-position:center center;
	display:block;
	height:100%;
	width:100%;
}
.comment_media_more{
	float:right;
	margin-top:5px;
}
.comment_comments .comment_btns{
	clear:both;
	margin-bottom:0.625rem;
}
.comment_comments .comment_btns a{
	font-size:var(--theme-font-size-small);
}
.comment_comments_options{
	display:flex;
	position:absolute !important;
	gap:0.625rem;
	right:0;
}
[dir="rtl"] .comment_comments_options{
	left:0;
	right:auto;
}
.comment_comments_options .comment_comments_options_icon{
	color:var(--theme-font-color-light);
}
.comment_comments_options_icon i{
	font-size:16px;
	height:15px;
	width:15px;
}
.comments > ul > li:hover > .comments_info > .comment_comments_options,
.comment_replies > ul > li:hover > .comments_info > .comment_comments_options{
	display:flex;
}
.comments_translate_link{
	margin:0 5px 0 0;
}
[dir="rtl"] .comments_translate_link{
	margin:0 0 0 5px;
}
/*Replies*/
.comment_replies{
	width:100%;
}
.comment_replies > ul > li{
	display:table;
	padding:0.625rem 0.3125rem 0;
	width:100%;
}
.comment_replies > ul > li > div{
	display:table-cell;
	vertical-align:top;
}
.comment_replies .comments_author_photo img{
	height:1.875rem;
	width:1.875rem;
}
.comment_replies > ul > li > div.comment_form_container,
.comment_replies > ul > li > div.comments_reply_info{
	width:100%;
}
.activity_feed .comment-feed .comments_reply,
.activity_feed .comment-feed .comments_reply_body{
	word-break:break-all;
}
.activity_feed .comment-feed .comments_reply_body img{
  width:100%;	
	border-radius:10px;
}
/*Stats*/
.comment_comments .comment_stats{
	border-width:1px 0;
	padding:0.625rem 0;
	margin:0.625rem 0;
	display:flex;
	align-items:center;
	justify-content:space-between;
}
.comment_comments .comment_stats > div{
	display:flex;
}
.comment_stats .comments_stats_likes{
	gap:0.5rem;
	white-space:nowrap;
}
.comments .comments_likes,
.comments .comments_viewall{
	font-size:100%;
}
.comments .comments_viewall a{
	font-weight:var(--theme-font-weight-bold);
}
.comments_likes_reactions a{
	display:inline-block;
	vertical-align:sub;
	text-decoration:none !important;
}
.comments_likes_reactions a:first-child{
	margin-right:-2px;
}
[dir="rtl"] .comments_likes_reactions a:first-child{
	margin-right:0;
	margin-left:-2px;
}
.comments_likes_reactions a:nth-child(n+2){
	margin-left:-10px;
	position:relative;
	z-index:1;
}
[dir="rtl"] .comments_likes_reactions a:nth-child(n+2){
	margin-left:0;
	margin-right:-6px;
}
.comments_likes_reactions a:nth-child(n+2):before{
	content:"";
	position:absolute;
	width:15px;
	height:18px;
	border-radius:50px;
	z-index:-1;
	left:-2px;
	right:0;
	top:-1px;
	margin:auto;
	display:block;
}
[dir="rtl"] .comments_likes_reactions a:nth-child(n+2):before{
	right:-2px;
	left:0;
}
.comments_likes_reactions a i{
	background-size:100%;
	display:block;
	height:14px;
	width:14px;
	border-radius:50px;
}
.comment_comments .comment_stats .comments_stats_comments{
	justify-content:flex-end;
	flex:1;
}
.comment_sort{
	float:right;
	padding:0.625rem 0;
}
.comment_view_more{
	padding:0.625rem 0;
}
.comment_sort .dropdown-toggle{
	color:var(--theme-font-color);
	display:flex;
	align-items:center;
}
.comment_sort .dropdown-toggle span{
	display:flex;
	gap:0.3125rem;
}
.comment_sort .dropdown-toggle span b{
	font-weight:normal;
}
.comment_comments .comment_stats .comments_stats_comments > a,
.comment_comments .comment_stats .comments_stats_comments > div{
	display:inline-block;
}
.comment_sort + .comment_more{
	width:auto;
	float:left;
}
.comment_sort + .comment_cnt_li,
.comment_more + li.comment_cnt_li{
	/* border-top-width:1px; */
	padding-top:0.625rem;
}
/*Add Video Popup*/
.comment_add_video_popup_wrapper{
	background-color:var(--theme-list-background-color);
	height:auto !important;
	padding:0 !important;
	width:100% !important;
}
.comment_add_video_popup_header{
	border-radius:3px 3px 0 0;
	border-bottom-width:1px;
	font-weight:bold;
	font-size:15px;
	padding:10px;
}
.comment_add_video_popup_cont{
	padding:10px;
}
.comment_add_video_popup_cont p{
	position:relative;
	padding:0 !important;
}
.comment_add_video_popup_cont input{
	padding:8px 10px;
	width:100%;
}
.comment_add_video_popup_cont input + img{
	position:absolute;
	right:0.3125rem;
	top:0.625rem;
}
.comment_add_video_popup_btm{
	border-top-width:1px;
	padding:0.625rem;
}
/*Comment Widget Placed on Pinboard*/
.pinboard_list_item .comments .comment_options{
	padding:0 10px;
}

/*Members List Popup CSS Start Here*/
.users_listing_popup{
	width:450px;
}
.users_listing_popup_header{
	background-color:var(--theme-list-background-color-alt);
	border-radius:3px 3px 0 0;
	font-weight:var(--theme-font-weight-bold);
	font-size:var(--theme-headline-size-medium);
	padding:0.625rem;
}
.users_listing_popup_tabs{
	margin:0 10px;
	border-bottom-width:1px;
}
.users_listing_popup_tabs ul{
	display:flex;
	gap:0.9375rem;
}
.users_listing_popup_tabs ul li a{
	font-weight:var(--theme-font-weight-bold);
	color:var(--font-color);
	height:50px;
	line-height:50px;
	display:block;
	text-decoration:none !important;
}
.users_listing_popup_tabs ul li.active a{
	border-bottom:1px solid var(--theme-color);
}
.users_listing_popup_tabs ul li a i{
	background-size:100%;
	display:inline-block;
	height:16px;
	width:16px;
	vertical-align:middle;
}
.users_listing_popup_cont_inner{
	padding:0 10px;
	overflow:auto;
	max-height:450px;
}
.users_listing_popup_cont_inner ._tip{
	padding:10px;
	text-align:center !important;
}
.users_listing_popup_item{
	display:flex;
	align-items:center;
	gap:0.625rem;
	padding:0.625rem 0;
	width:100%;
}
.users_listing_popup_item_photo span{
	position:relative;
	display:block;
}
.users_listing_popup_item_photo span i{
	background-size:100%;
	display:block;
	height:1rem;
	right:-0.1875rem;
	bottom:-0.1875rem;
	position:absolute;
	width:1rem;
}
[dir="rtl"] .users_listing_popup_item_photo span i{
	left:-0.1875rem;
	right:inherit;
}
.users_listing_popup_item_info{
	flex:1;
}
.users_listing_popup_item_title{
	font-weight:var(--theme-font-weight-bold);
}
.users_listing_popup_item_statsl{
	font-size:var(--theme-font-size-small);
}
.users_listing_popup_cont_tip{
	margin:10px 0;
}
.users_listing_popup_footer{
	border-top-width:1px;
	padding:10px;
}
.users_listing_popup_footer button{
	margin-right:5px;
}
/*Members List Popup CSS End Here*/

/* ADD LINK POPUP */
.comment_add_link_popup_wrapper{
	width:100% !important;
	height:auto !important;
}
.comment_add_link_popup_btm > button{
	margin:10px;
	margin-left:0;
}
.comment_add_link_popup_header{
	font-size:20px;
}
.comment_add_link_popup_cont{
	display:block;
  width:100%;
}
.comment_add_link_popup_cont input{
	width:100%;
}
.comment_comments .comments_date .feed_item_option_unlike a:before{
	display:none;
}
@media only screen and (max-width:979px){
	.users_listing_popup{
		width:100%;
	}
}
@media only screen and (max-width:768px){
	.comment_comments form .comment_form_main{
		flex-direction:column;
	}
	.comment_comments div.comment_post_options{
		justify-content:space-between;
		width:100%;
	}
	html .comment_comments div.comment_form_container .comment_form .jqueryHashtags .highlighter, 
	html .comment_comments div.comment_form_container   div.comment_form textarea{
		font-size:12px !important;
		line-height:16px !important;
    min-width:inherit !important;
	}
	html .activity_cd_p #feedbg_main_continer{
	  position:inherit;
		left:auto;
		right:auto;	
	}
	html .activity_post_container_wrapper #feedbg_content{
	  display:inline;	
	}
	.comment_comments form.advcomment_form > div.comment_form_container > button{
		display:block;
	}
}
@media(min-width:1024px){
	.comment_comments_options{
		display:none;
	}
	.comments > ul > li:hover > .comments_info > .comment_comments_options,
	.comments > ul > li:hover > .comments_info > .comments_translate_link, 
	.comment_replies > ul > li:hover > .comments_info >   .comments_translate_link{
    display:flex;
  }
}
