<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Comment_Bootstrap extends Engine_Application_Bootstrap_Abstract {

	public function __construct($application) {
		parent::__construct($application);
		$this->initViewHelperPath();
		$view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
		$view->headTranslate(array('Write a comment...', 'cancel'));
	}
}
