<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<script type="text/javascript">
  var contentAutocomplete =  'tags';
  en4.core.runonce.add(function() {
    var cache = {};
    scriptJquery('#tags').autocomplete({
      source: function (request, response) { 
        scriptJquery.ajax({
          url: '<?php echo $this->url(array('controller' => 'tag', 'action' => 'suggest'), 'default', true) ?>',
          data: { text: request.term },
          success: function (transformed) {
            response(transformed);
          },
          error: function () {
              response([]);
          }
        });
      },
      select: function(event, ui) { 
      },
    });
  });
</script>
<div class='settings'>
  <?php echo $this->form->render($this); ?>
</div>
