<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="comment_emotion_search_content">
  <?php
  if (engine_count($this->files)) { ?>
    <ul class="_sickers">
      <?php
      foreach ($this->files as $key => $file) { ?>
        <?php if (!empty($file->files_id)) { ?>
          <li rel="<?php echo $file->files_id; ?>">
            <a href="javascript:;" class="_simemoji_reaction">
              <img src="<?php echo Engine_Api::_()->storage()->get($file->photo_id, '')->getPhotoUrl(); ?>" alt="" />
            </a>
          </li>
        <?php } ?>
        <?php
      } ?>
    </ul>
    <?php
  } else {
    ?>
    <div class="comment_emotion_search_noresult">
      <i class="far fa-frown font_color_light" aria-hidden="true"></i>
      <span class="font_color_light"><?php echo $this->translate("No Stickers to Show") ?></span>
    </div>
  <?php } ?>
</div>
<?php die; ?>