<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="comment_contact_popup " id="comment_contact_popup">
	<div><?php echo $this->form->render(); ?></div>
</div>